******
Clique
******

.. automodule:: networkx.algorithms.clique
.. autosummary::
   :toctree: generated/

   find_cliques
   make_max_clique_graph
   make_clique_bipartite        
   graph_clique_number
   graph_number_of_cliques      
   node_clique_number
   number_of_cliques
   cliques_containing_node

